==> Evergreen-ILS-3.15.7.tar.gz: Evergreen-ILS-3.15.7/Open-ILS/web/js/dojo/openils/circ/nls/oc-fr/selfcheck.js <==
{
    ":TOTAL_ITEMS_SESSION": "Total items this session: ${0}.",
    ":TOTAL_ITEMS_ACCOUNT": "Total items on account:  ${0}.",
    ":HOLDS_READY_FOR_PICKUP": "You have ${0} item(s) ready for pickup.",
    ":TOTAL_HOLDS": "You have ${0} total holds.",
    ":TOTAL_FINES_ACCOUNT": "Total fines on account: $${0}.",
    ":HOLD_STATUS_READY": "Ready for pickup",
    ":HOLD_STATUS_WAITING": "#${0} in line with ${1} copies",
    ":CHECKOUT_SUCCESS": "Checkout of item ${0} succeeded",
    ":RENEW_SUCCESS": "Renewal of item ${0} succeeded",
    ":ALREADY_OUT": "Item ${0} is already checked out",
    ":OPEN_CIRCULATION_EXISTS": "Item ${0} is already checked out to another user",
    ":GENERIC_CIRC_FAILURE": "Unable to check out item ${0}.  Please see staff.",
    ":LOGIN_FAILED": "Login for ${0} failed",
    ":UNKNOWN_ERROR": "An unhandled exception occurred with error code ${0}",
    ":MAX_RENEWALS": "No more renewals allowed for item ${0}",
    ":ITEM_NOT_CATALOGED": "Item ${0} was not found in the system.  Try re-scanning the item.",
    ":WORKSTATION_REQUIRED": "A workstation is required to log in to selfcheck.  You can set the  workstation name with URL param 'ws'.  \n\nWould you like to register a new workstation for this self-check interface?",
    ":WORKSTATION_EXISTS": "This workstation has already been registered.  Would you like to use it for this self-check station?",
    ":CC_PAYABLE_BALANCE": "Total amount to pay: $${0}",
    ":TOTAL_FINES_SELECTED": "Total d\u2019elements seleccionats : $${0}",
    ":WELCOME_BANNER": "Benvenguda, ${0}",
    ":ENTER_PASSWORD": "Please enter your password",
    ":PLEASE_LOGIN": "Please log in with your username or library barcode.",
    ":ENTER_BARCODE": "Please enter an item barcode",
    ":MISCELLANEOUS": "Miscellaneous",
    ":FAIL_PART_actor_usr_barred": "The patron is barred",
    ":FAIL_PART_asset_copy_circulate": "The item does not circulate",
    ":FAIL_PART_asset_copy_location_circulate": "Items from this shelving location do not circulate",
    ":FAIL_PART_asset_copy_status": "The item cannot circulate at this time",
    ":FAIL_PART_circ_holds_target_skip_me": "The item's circulation library does not fulfill holds",
    ":FAIL_PART_config_circ_matrix_circ_mod_test": "The patron has too many items of this type checked out",
    ":FAIL_PART_config_circ_matrix_test_available_copy_hold_ratio": "The available item-to-hold ratio is too low",
    ":FAIL_PART_config_circ_matrix_test_circulate": "Circulation rules reject this item as non-circulatable",
    ":FAIL_PART_config_circ_matrix_test_total_copy_hold_ratio": "The total item-to-hold ratio is too low",
    ":FAIL_PART_config_hold_matrix_test_holdable": "Hold rules reject this item as unholdable",
    ":FAIL_PART_config_hold_matrix_test_max_holds": "The patron has reached the maximum number of holds",
    ":FAIL_PART_item.holdable": "The item is not holdable",
    ":FAIL_PART_location.holdable": "The item's location is not holdable",
    ":FAIL_PART_status.holdable": "The item is not in a holdable status",
    ":FAIL_PART_config_rule_age_hold_protect_prox": "The item is too new to transit this far",
    ":FAIL_PART_no_item": "Client introbable",
    ":FAIL_PART_no_ultimate_items": "The system could not find any items to match this hold request",
    ":FAIL_PART_monographic_part_required": "Title hold request invalid when monographic part required",
    ":FAIL_PART_no_matchpoint": "System rules do not define how to handle this item",
    ":FAIL_PART_no_user": "Client introbable",
    ":FAIL_PART_transit_range": "The item cannot transit this far",
    ":PAYMENT_INVALID_USER_XACT_ID": "We cannot proceed with the payment, because your account was updated from another location.  Please refresh the interface or log out and back in to retrieve the latest account information"
}

==> Evergreen-ILS-3.16.1.tar.gz: Evergreen-ILS-3.16.1/Open-ILS/web/js/dojo/openils/circ/nls/oc-fr/selfcheck.js <==
{
    ":TOTAL_ITEMS_SESSION": "Total items this session: ${0}.",
    ":TOTAL_ITEMS_ACCOUNT": "Nombre de documents associats al compte : <b>${0}</b>.",
    ":HOLDS_READY_FOR_PICKUP": "You have ${0} item(s) ready for pickup.",
    ":TOTAL_HOLDS": "You have ${0} total holds.",
    ":TOTAL_FINES_ACCOUNT": "Total fines on account: $${0}.",
    ":HOLD_STATUS_READY": "Ready for pickup",
    ":HOLD_STATUS_WAITING": "#${0} in line with ${1} copies",
    ":CHECKOUT_SUCCESS": "Checkout of item ${0} succeeded",
    ":RENEW_SUCCESS": "Renewal of item ${0} succeeded",
    ":ALREADY_OUT": "Item ${0} is already checked out",
    ":OPEN_CIRCULATION_EXISTS": "Item ${0} is already checked out to another user",
    ":GENERIC_CIRC_FAILURE": "Unable to check out item ${0}.  Please see staff.",
    ":LOGIN_FAILED": "Login for ${0} failed",
    ":UNKNOWN_ERROR": "An unhandled exception occurred with error code ${0}",
    ":MAX_RENEWALS": "No more renewals allowed for item ${0}",
    ":ITEM_NOT_CATALOGED": "Item ${0} was not found in the system.  Try re-scanning the item.",
    ":WORKSTATION_REQUIRED": "A workstation is required to log in to selfcheck.  You can set the  workstation name with URL param 'ws'.  \n\nWould you like to register a new workstation for this self-check interface?",
    ":WORKSTATION_EXISTS": "This workstation has already been registered.  Would you like to use it for this self-check station?",
    ":CC_PAYABLE_BALANCE": "Total amount to pay: $${0}",
    ":TOTAL_FINES_SELECTED": "Total d\u2019elements seleccionats : $${0}",
    ":WELCOME_BANNER": "Benvenguda, ${0}",
    ":ENTER_PASSWORD": "Please enter your password",
    ":PLEASE_LOGIN": "Please log in with your username or library barcode.",
    ":ENTER_BARCODE": "Please enter an item barcode",
    ":MISCELLANEOUS": "Miscellaneous",
    ":FAIL_PART_actor_usr_barred": "The patron is barred",
    ":FAIL_PART_asset_copy_circulate": "The item does not circulate",
    ":FAIL_PART_asset_copy_location_circulate": "Items from this shelving location do not circulate",
    ":FAIL_PART_asset_copy_status": "The item cannot circulate at this time",
    ":FAIL_PART_circ_holds_target_skip_me": "The item's circulation library does not fulfill holds",
    ":FAIL_PART_config_circ_matrix_circ_mod_test": "The patron has too many items of this type checked out",
    ":FAIL_PART_config_circ_matrix_test_available_copy_hold_ratio": "The available item-to-hold ratio is too low",
    ":FAIL_PART_config_circ_matrix_test_circulate": "Circulation rules reject this item as non-circulatable",
    ":FAIL_PART_config_circ_matrix_test_total_copy_hold_ratio": "The total item-to-hold ratio is too low",
    ":FAIL_PART_config_hold_matrix_test_holdable": "Hold rules reject this item as unholdable",
    ":FAIL_PART_config_hold_matrix_test_max_holds": "The patron has reached the maximum number of holds",
    ":FAIL_PART_item.holdable": "The item is not holdable",
    ":FAIL_PART_location.holdable": "The item's location is not holdable",
    ":FAIL_PART_status.holdable": "The item is not in a holdable status",
    ":FAIL_PART_config_rule_age_hold_protect_prox": "The item is too new to transit this far",
    ":FAIL_PART_no_item": "Client introbable",
    ":FAIL_PART_no_ultimate_items": "The system could not find any items to match this hold request",
    ":FAIL_PART_monographic_part_required": "Title hold request invalid when monographic part required",
    ":FAIL_PART_no_matchpoint": "System rules do not define how to handle this item",
    ":FAIL_PART_no_user": "Client introbable",
    ":FAIL_PART_transit_range": "The item cannot transit this far",
    ":PAYMENT_INVALID_USER_XACT_ID": "We cannot proceed with the payment, because your account was updated from another location.  Please refresh the interface or log out and back in to retrieve the latest account information"
}
